﻿using Infragistics.Win;
using Infragistics.Win.UltraWinEditors;
using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace WindowsFormsApp44
{
    class UltraTrackBarDrawFilter : IUIElementDrawFilter
    {
        public bool DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {
            switch (drawPhase)
            {               
                case DrawPhase.AfterDrawBackColor:
                    {
                        var trackUIElement = drawParams.Element as TrackUIElement;
                        if (null == trackUIElement)
                            return false;

                        var trackBarEmbeddableUIElement = trackUIElement.GetAncestor(typeof(TrackBarEmbeddableUIElement)) as TrackBarEmbeddableUIElement;
                        if (null == trackBarEmbeddableUIElement)
                            return false;

                        var editor = trackBarEmbeddableUIElement.Editor as TrackBarEditor;
                        if (null == editor)
                            return false;

                        var trackBar = trackBarEmbeddableUIElement.Control as UltraTrackBar;
                        if (null == trackBar)
                            return false;

                        // We need to determine the rect of the track to the left of the thumb. 
                        // All of this code assumes that the TrackBar is in horizontal orientation. 

                        // Get the rect of the track. 
                        var trackUIElementRect = trackUIElement.DrawingRect;

                        // Get the point based on the Value and add half the width of the thumb. 
                        var value = trackBar.Value;
                        int pointFromValue = trackBarEmbeddableUIElement.GetPointFromValue(value);
                        int thumbOffset = editor.ThumbSizeResolved.Width / 2;

                        // Now we can calculate the rect to the left of the thumb. This is the
                        // same as the track rect, but we just change the width. 
                        Rectangle leftOfThumbRect = new Rectangle(
                           trackUIElementRect.X,
                           trackUIElementRect.Y,
                           pointFromValue + thumbOffset,
                           trackUIElementRect.Height
                           );

                        // Draw over the existing track. 
                        drawParams.Graphics.FillRectangle(Brushes.Green, leftOfThumbRect);
                    }
                    break;
            }

            return false;
        }

        public DrawPhase GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {
            if (drawParams.Element is TrackUIElement)
                return DrawPhase.AfterDrawBackColor;

            return DrawPhase.None;
        }
    }
}
